@@ -67,8 +67,8 @@ class Module:
         '''
         _bf_limit = 50
         _ss_limit = 50
-        self.biological_features = tuple()
-        self.sample_sets = tuple()
+        self.biological_features = None
+        self.sample_sets = None
         if biofeatures:
             self.biological_features = tuple(biofeatures)
         if samplesets:
@@ -97,9 +97,9 @@ class Module:
             # get first _bf_limit biofeatures automatically
             _bf = self.compendium.rank_biological_features(self, rank_method=_rank, cutoff=cutoff)
             _bf = _bf['ranking']['id'][:_bf_limit]
-            self.biological_features = BiologicalFeature.using(self.compendium).get(
+            self.biological_features = tuple(BiologicalFeature.using(self.compendium).get(
                 filter={'id_In': str(_bf)}
-            )
+            ))
         elif self.sample_sets is None:
             all_ranks = self.compendium.get_score_rank_methods()['sampleSets']
             _rank = rank
@@ -112,9 +112,9 @@ class Module:
             # get first _ss_limit samplesets automatically
             _ss = self.compendium.rank_sample_sets(self, rank_method=_rank, cutoff=cutoff)
             _ss = _ss['ranking']['id'][:_ss_limit]
-            self.sample_sets = SampleSet.using(self.compendium).get(
+            self.sample_sets = tuple(SampleSet.using(self.compendium).get(
                 filter={'id_In': str(_ss)}
-            )
+            ))
         # now we biofeatures and samplesets
         setattr(self, '__normalized_values__', None)
         self.values
